==> k4de-0.3.0.tgz: k4de-0.3.0/src/kde/widgets/sliderwidget.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** sliderwidget.h
*/
#ifndef __SliderWidget_H__
#define __SliderWidget_H__

#include <qwidget.h>
#include <qlabel.h>
#include <qtooltip.h>
//#include <qslider.h>
#include <qsize.h>

class QSlider;
class	 SliderWidget : public QWidget
{
Q_OBJECT
protected:
	
        QSlider *slider;
	QLabel *label,*valuel;
	int value;

public:
	SliderWidget(QWidget *parent,char*n="",int v=0,int mi=0,int ma=100);
	~SliderWidget();

	int	getValue();
	void	setValue(int);

public slots:
	void	paintEvent(QPaintEvent *);
        void 	changed(int);

};


#endif

==> k4de-0.4.0.tgz: k4de-0.4.0/src/kde/widgets/sliderwidget.h <==
/******************************************************************************
**                                                                           **
**    k4de - 3d-editor for the K Desktop Enviroment                          **
**                                                                           **
**    Copyright (C) 1999  Tobias Wollgam (tobias.wollgam@gmx.de)             **
**    Copyright (C) 1999  Markus Weber (mweber@gmx.de)                       **
**                                                                           **
**    This program is free software; you can redistribute it and/or modify   **
**    it under the terms of the GNU General Public License as published by   **
**    the Free Software Foundation; either version 2 of the License, or      **
**    (at your option) any later version.                                    **
**                                                                           **
**    This program is distributed in the hope that it will be useful,        **
**    but WITHOUT ANY WARRANTY; without even the implied warranty of         **
**    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          **
**    GNU General Public License for more details.                           **
**                                                                           **
**    You should have received a copy of the GNU General Public License      **
**    along with this program; if not, write to the Free Software            **
**    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.              **
**                                                                           **
******************************************************************************/
/*
** sliderwidget.h
*/
#ifndef __SliderWidget_H__
#define __SliderWidget_H__

#include <qwidget.h>
#include <qlabel.h>
#include <qtooltip.h>
//#include <qslider.h>
#include <qsize.h>

class QSlider;
class	 SliderWidget : public QWidget
{
Q_OBJECT
protected:
	
        QSlider *slider;
	QLabel *label,*valuel;
	int value;

public:
	SliderWidget(QWidget *parent,const char*n="",int v=0,int mi=0,int ma=100);
	~SliderWidget();

	int	getValue();
	void	setValue(int);

public slots:
	void	paintEvent(QPaintEvent *);
        void 	changed(int);

signals:
	void 	valueChanged();
};


#endif
